@@ -135,7 +135,7 @@ def load():
 
                 return render_template("load.html")
 
-            if load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}"):
+            if load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[0]:
 
                 group_name = load_list.load_slush()
                 groups_dir[group_name] = load_list
@@ -145,14 +145,33 @@ def load():
                 flash(message, category='success')
 
                 return render_template("load.html")
-            else:
 
-                os.remove(f"{UPLOAD_FOLDER}/{filename}")
+            elif not load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[0]:
 
-                message = "Введенные данные указаны неверно"
+                error_name = load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[1]
+
+                if load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[2] in ['len', 'count']:
+                    message = f"Некорректно указан fullname -> {error_name}." \
+                            f"Пример: {year}-{number}-<год_поступления>-<первые_три_буквы_фамилии>"
+
+                elif load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[2] == 'year':
+
+                    access_name = error_name.replace(error_name.split('-')[0], year)
+
+                    message = f"Некорректно указан fullname -> {error_name}." \
+                              f"Исправьте на {access_name}"
+
+                elif load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[2] == 'num':
+
+                    access_name = error_name.replace(error_name.split('-')[1], number)
+
+                    message = f"Некорректно указан fullname -> {error_name}." \
+                              f"Исправьте на {access_name}"
 
                 flash(message, category='error')
 
+                os.remove(f"{UPLOAD_FOLDER}/{filename}")
+
                 return render_template("load.html")
         else:
 
@@ -199,18 +218,20 @@ def slushlist(number):
     with open(f"{UPLOAD_FOLDER}/{number}.txt", 'r') as fl_link:
         for line in fl_link:
 
-            if line[0] == "#":
-                continue
+            if not line.isspace():
 
-            fio, fullname, login = line.split(';')
-            login = login[:-1]
-            del fio
+                if line[0] == "#":
+                    continue
 
-            slush.append(fullname)
-            slush.append(login)
-            sl_list.append((list(slush)))
+                fio, fullname, login = line.split(';')
+                login = login[:-1]
+                del fio
 
-            slush.clear()
+                slush.append(fullname)
+                slush.append(login)
+                sl_list.append((list(slush)))
+
+                slush.clear()
 
     return render_template("sllist.html", sl_list=sl_list, number=number)
 
@@ -351,14 +372,14 @@ def rename():
 
         if gr_year != new_fullname[0]:
 
-            message = 'Не верно указан год поступления в новом fullname'
+            message = 'Неверно указан год поступления в новом fullname'
             flash(message, category='error')
 
             return render_template("rename.html", group=group)
 
         if gr_num != new_fullname[1]:
 
-            message = 'Не верно указан порядковый номер группы в новом fullname'
+            message = 'Неверно указан порядковый номер группы в новом fullname'
             flash(message, category='error')
 
             return render_template("rename.html", group=group)
@@ -432,8 +453,6 @@ def repos():
 
             return render_template("getrepos.html", group=group)
 
-        sl_list = []
-
         if choice == 'repo':
             flag = '-r'
             sl_list = get_repos(number_group, repo_name, flag)
